==> ifrit_3.2.0.orig.tar.gz: ifrit-3.2.0/core/icameraorthoactor.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A small actor that shows camera orientation when it is orthogonal
//
#ifndef ICAMERAORTHOACTOR_H
#define ICAMERAORTHOACTOR_H


#include <vtkActor2D.h>


#include "ipointermacro.h"

class iTextBitmap;
class iOverlayHelper;
class iRenderTool;

class vtkAxisActor2D;
class vtkCamera;


class iCameraOrthoActor : public vtkActor2D
{

	IPOINTER_AS_USER(OverlayHelper);

public:

	vtkTypeMacro(iCameraOrthoActor,vtkActor2D);
	static iCameraOrthoActor* New(iRenderTool *rt = 0);

	virtual int RenderOverlay(vtkViewport *vp);
	virtual int RenderOpaqueGeometry(vtkViewport *vp);
	virtual int RenderTranslucentGeometry(vtkViewport *vp);

	virtual void ReleaseGraphicsResources(vtkWindow *win);

protected:

	virtual ~iCameraOrthoActor();

private:

	iCameraOrthoActor(iRenderTool *rv);

	bool mDoOverlay;
	vtkAxisActor2D *mActors[2];
	iTextBitmap *mLabels[2];
};

#endif

==> ifrit_3.3.2.orig.tar.gz: ifrit-3.3.2/core/icameraorthoactor.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A small actor that shows camera orientation when it is orthogonal
//
#ifndef ICAMERAORTHOACTOR_H
#define ICAMERAORTHOACTOR_H


#include "igenericprop.h"
#include <vtkActor2D.h>


#include "ipointermacro.h"

class iTextActor;
class iOverlayHelper;
class iRenderTool;

class vtkAxisActor2D;
class vtkCamera;


class iCameraOrthoActor : public iGenericProp<vtkActor2D>
{

	IPOINTER_AS_USER(OverlayHelper);

public:

	vtkTypeMacro(iCameraOrthoActor,vtkActor2D);
	static iCameraOrthoActor* New(iRenderTool *rt = 0);

protected:

	virtual ~iCameraOrthoActor();

	virtual void UpdateGeometry(vtkViewport *vp);

private:

	iCameraOrthoActor(iRenderTool *rv);

	vtkAxisActor2D *mActors[2];
	iTextActor *mLabels[2];
};

#endif
